```json
{
  "title": "MN 37 The Shorter Craving-Destruction Discourse | Cūḷa Taṇhāsaṅkhaya Sutta",
  "author": "",
  "site": "sutta on dhammatalks.org",
  "published": ""
}
```

## The Shorter Craving-Destruction Discourse Cūḷa Taṇhāsaṅkhaya Sutta (MN 37)

I have heard that on one occasion the Blessed One was staying near Sāvatthī in the Eastern Monastery, the palace of Migāra’s mother.

Then Sakka the deva-king went to the Blessed One and, on arrival, having bowed down to him, stood to one side. As he was standing there, he said to the Blessed One, “Briefly, lord, in what respect is a monk released through the ending of craving, utterly complete, utterly free from bonds, a follower of the utterly holy life, utterly consummate: foremost among devas & human beings?” [^1]

“There is the case, deva-king, where a monk has heard, ‘All dhammas are unworthy of adherence.’ [^2] Having heard that all dhammas are unworthy of adherence, he directly knows every dhamma. Directly knowing every dhamma, he comprehends every dhamma. Comprehending every dhamma, then whatever feeling he experiences—pleasure, pain, neither pleasure nor pain—he remains focused on inconstancy, focused on dispassion, focused on cessation, focused on relinquishing with regard to that feeling.[^3] As he remains focused on inconstancy, focused on dispassion, focused on cessation, focused on relinquishing with regard to that feeling, he is unsustained by \[doesn’t cling to\] anything in the world. Unsustained, he isn’t agitated. Unagitated, he totally unbinds right within. He discerns: ‘Birth is ended, the holy life fulfilled, the task done. There is nothing further for this world.’

“It’s in this respect, deva-king, that a monk, in brief, is released through the ending of craving, utterly complete, utterly free from bonds, a follower of the utterly holy life, utterly consummate: foremost among devas & human beings.”

Then Sakka the deva-king, delighting in & approving of the Buddha’s words, bowed down & circumambulated him—keeping him to his right—and then vanished right there.

Now, on that occasion Ven. Mahā Moggallāna was sitting not far from the Blessed One. The thought occurred to him, “Did that spirit approve of the Blessed One’s words having broken through to them, or not? What if I were to find out whether he approved of the Blessed One’s words having broken through to them or not?”

Then—just as a strong man might extend his flexed arm or flex his extended arm—Ven. Mahā Moggallāna vanished from the palace of Migāra’s mother in the Eastern Monastery and reappeared among the devas of the Thirty-three.

Now, on that occasion, Sakka the deva-king was enjoying himself in the Pleasure Park of the Single White Lotus Flower, furnished & replete with the sound of 500 heavenly musicians. He saw Ven. Mahā Moggallāna coming from afar, and on seeing him, dismissed the 500 heavenly musicians and went to him. On arrival, he said to him, “Come, dear sir Moggallāna. Welcome, dear sir Moggallāna. It’s been a long time, dear sir Moggallāna, since you’ve made your way here. Sit down, dear sir Moggallāna. This seat is made ready.”

Then Ven. Mahā Moggallāna sat down on the seat made ready, while Sakka the deva-king sat down to one side, taking a lower seat.

When Sakka the deva-king had taken his seat, Ven. Mahā Moggallāna said to him, “Kosiya,[^4] how did the Blessed One describe to you in brief the release through the ending of craving? It would be good if we, too, could get to share in hearing that talk.”

“Dear sir, Moggallāna, many are our duties, many our responsibilities: not only our own responsibilities but also the responsibilities of the devas of the Thirty-three. On top of that, even what is well-heard, well-grasped, well-attended to, well-remembered by us suddenly vanishes.

“Once, dear sir Moggallāna, a war was raging between the devas & the asuras, and in that war the devas won and the asuras lost. Having won that war and returned as victor, I had the Vejayanta (Victory) Palace built. Dear sir Moggallāna, the Vejayanta Palace has 100 wings. Each wing has seven times 700 gabled halls; each gabled hall has seven times seven nymphs; each nymph has seven times seven handmaids. Would you like to see the delightful features of the Vejayanta Palace, dear sir Moggallāna?”

Ven. Mahā Moggallāna accepted with silence.

Then Sakka the deva-king & the Great King Vessavaṇṇa,[^5] giving precedence to Ven. Mahā Moggallāna, went to the Vejayanta palace. The handmaids of Sakka the deva-king saw Ven. Mahā Moggallāna coming in the distance and, on seeing him, feeling embarrassed & ashamed, went each into her own room. Just as a daughter-in-law, on seeing her father-in-law, is embarrassed & ashamed, even so the handmaids of Sakka the deva-king, on seeing Ven. Mahā Moggallāna and feeling embarrassed & ashamed, went each into her own room.

Then Sakka the deva-king & the Great King Vessavaṇṇa had Ven. Mahā Moggallāna walk all around, exploring the Vejayanta Palace, (saying,) “Look at this delightful feature of the Vejayanta Palace, dear sir Moggallāna! Look at this delightful feature of the Vejayanta Palace, dear sir Moggallāna!”

“This outshines Ven. Kosiya as one who has made merit in the past. Just as whenever human beings, on seeing something delightful, say, ‘How this outshines, good sirs, the devas of the Thirty-three!’ in the same way, this outshines Ven. Kosiya as one who has made merit in the past.”

Then the thought occurred to Ven. Mahā Moggallāna, “This spirit is living far too heedlessly.[^6] What if I were to inspire a sense of terror *\[saṁvega\]* in this spirit?”

So Ven. Mahā Moggallāna fabricated a fabrication of psychic power such that with his toe he made the Vejayanta Palace shiver & quiver & quake. Then the minds of Sakka the deva-king & the Great King Vessavaṇṇa & the devas of the Thirty-three were overcome with amazement & astonishment: “How amazing, good sirs! How astounding, good sirs!—the great power, the great might of this contemplative, in that with his toe he makes the deva palace shiver & quiver & quake!”

Then Ven. Mahā Moggallāna, knowing that Sakka the deva-king was in terror, his hair standing on end, said to him, “Kosiya, how did the Blessed One describe to you in brief the release through the ending of craving? It would be good if we, too, could get to share in hearing that talk.”

“Just now, dear sir Moggallāna, I went to the Blessed One and, on arrival, having bowed down to him, stood to one side. As I was standing there, I said to the Blessed One, ‘Briefly, lord, in what respect is a monk released through the ending of craving, utterly complete, utterly free from bonds, a follower of the utterly holy life, utterly consummate: foremost among devas & human beings?’

“When this was said, the Blessed One said to me: ‘There is the case, deva-king, where a monk has heard, “All dhammas are unworthy of adherence.” Having heard that all dhammas are unworthy of adherence, he directly knows every dhamma. Directly knowing every dhamma, he comprehends every dhamma. Comprehending every dhamma, then whatever feeling he experiences—pleasure, pain, neither pleasure nor pain—he remains focused on inconstancy, focused on dispassion, focused on cessation, focused on relinquishing with regard to that feeling. As he remains focused on inconstancy, focused on dispassion, focused on cessation, focused on relinquishing with regard to that feeling, he is unsustained by \[doesn’t cling to\] anything in the world. Unsustained, he isn’t agitated. Unagitated, he totally unbinds right within. He discerns: “Birth is ended, the holy life fulfilled, the task done. There is nothing further for this world.”

“‘It’s in this respect, deva-king, that a monk, in brief, is released through the ending of craving, utterly complete, utterly free from bonds, a follower of the utterly holy life, utterly consummate: foremost among devas & human beings.’

“That is how, dear sir Moggallāna, the Blessed One described to me in brief the release through the ending of craving.”

Then Ven. Mahā Moggallāna, delighting in & approving of Sakka the deva-king’s words—as a strong man might extend his flexed arm or flex his extended arm—vanished from among the devas of the Thirty-three and reappeared in the palace of Migāra’s mother in the Eastern Monastery.

Then not long after Ven. Mahā Moggallāna had left, the handmaids of Sakka the deva-king said to him, “Dear sir, is that Blessed One your teacher?”

“No, that Blessed One isn’t my teacher. That is Ven. Mahā Moggallāna, my fellow in the holy life.” [^7]

“It’s a gain for you, dear sir, a great gain for you, dear sir, in that you have a fellow in the holy life of such great power, such great might! How much more so will the Blessed One, your teacher be!”

Then Ven. Mahā Moggallāna went to the Blessed One and, on arrival, having bowed down to him, sat to one side. As he was sitting there, he said to the Blessed One, “Does the Lord Blessed One recall describing in brief the release through the ending of craving to a certain spirit with a great following?”

“I recall, Moggallāna, that just now Sakka the deva-king approached me and, on arrival, having bowed down to me, stood to one side. As he was standing there, he said to me, ‘Briefly, lord, in what respect is a monk released through the ending of craving, utterly complete, utterly free from bonds, a follower of the utterly holy life, utterly consummate: foremost among devas & human beings?’

“When this was said, I said to him: ‘There is the case, deva-king, where a monk has heard, “All dhammas are unworthy of adherence.” Having heard that all dhammas are unworthy of adherence, he directly knows every dhamma. Directly knowing every dhamma, he comprehends every dhamma. Comprehending every dhamma, then whatever feeling he experiences—pleasure, pain, neither pleasure nor pain—he remains focused on inconstancy, focused on dispassion, focused on cessation, focused on relinquishing with regard to that feeling. As he remains focused on inconstancy, focused on dispassion, focused on cessation, focused on relinquishing with regard to that feeling, he is unsustained by \[doesn’t cling to\] anything in the world. Unsustained, he isn’t agitated. Unagitated, he totally unbinds right within. He discerns: “Birth is ended, the holy life fulfilled, the task done. There is nothing further for this world.”

“‘It’s in this respect, deva-king, that a monk, in brief, is released through the ending of craving, utterly complete, utterly free from bonds, a follower of the utterly holy life, utterly consummate: foremost among devas & human beings.’

“That, Moggallāna, is how I recall describing to Sakka the deva-king in brief the release through the ending of craving.”

That is what the Blessed One said. Gratified, Ven. Mahā Moggallāna delighted in the Blessed One’s words.

See also: [SN 27:1–10](https://120-dhammatalks-footnotes/suttas/SN/SN27_1.html); [SN 46:26](https://120-dhammatalks-footnotes/suttas/SN/SN46_26.html); [Sn 5:8](https://120-dhammatalks-footnotes/suttas/KN/StNp/StNp5_8.html)

[^1]: According to [AN 7:58](https://120-dhammatalks-footnotes/suttas/AN/AN7_58.html), this is the question that Ven. Mahā Moggallāna asked the Buddha before he attained arahantship. The Buddha’s answer here is the same as he gave in that discourse. So it’s appropriate that Moggallāna, on hearing the Buddha give this answer to Sakka, should be curious as to how thoroughly Sakka understood the meaning. If he had truly taken it to heart, he would have attained arahantship just as Moggallāna had.

[^2]: The Commentary identifies “all dhammas” here as three sorts of fabricated dhammas: the five aggregates, the twelve sense media, and the eighteen properties (the twelve sense media plus the consciousness appropriate to each sense organ). This, however, misses the point that “all dhammas” in other contexts include not only fabricated dhammas but also unfabricated dhammas. ([Iti 90](https://120-dhammatalks-footnotes/suttas/KN/Iti/iti90.html); [Dhp 277–279](https://120-dhammatalks-footnotes/suttas/KN/Dhp/Ch20.html#dhp277)).

It should also be noted that the Buddha gives the teaching that all dhammas are unworthy of adherence only to those who have already attained the Dhamma eye. As [AN 9:36](https://120-dhammatalks-footnotes/suttas/AN/AN9_36.html) shows, such people still have desire and passion for the experience of the deathless. To attain arahantship, they have to abandon that desire and passion as well. And because the statement, “All dhammas are unworthy of adherence” is also a dhamma, there comes a point where it, too, has to be abandoned. For other references to the abandoning of right view, see [MN 22](https://120-dhammatalks-footnotes/suttas/MN/MN22.html), [SN 48:3](https://120-dhammatalks-footnotes/suttas/SN/SN48_3.html), [SN 48:4](https://120-dhammatalks-footnotes/suttas/SN/SN48_4.html), and [AN 10:93](https://120-dhammatalks-footnotes/suttas/AN/AN10_93.html)

As for those who have yet to attain the Dhamma eye, they shouldn’t be in a hurry to abandon right view. They first have to attain to it, verifying their conviction in it by confirming that the Dhamma is true ([MN 70](https://120-dhammatalks-footnotes/suttas/MN/MN70.html)). Only in the very last stages of the practice should all dhammas be abandoned. See [MN 22](https://120-dhammatalks-footnotes/suttas/MN/MN22.html)

[^3]: The sequence here—“focused on inconstancy, focused on dispassion, focused on cessation, focused on relinquishing”—follows the same pattern as the last four steps in the Buddha’s description of mindfulness of breathing. See [MN 118](https://120-dhammatalks-footnotes/suttas/MN/MN118.html)

[^4]: “Owl,” Sakka’s clan name.

[^5]: One of the Four Great Kings. Vessavaṇṇa is the king of the north, ruling over the yakkhas.

[^6]: According to [DN 21](https://120-dhammatalks-footnotes/suttas/DN/DN21.html), Sakka is a stream-enterer. However, [SN 55:40](https://120-dhammatalks-footnotes/suttas/SN/SN55_40.html) describes how a stream-enterer can still be heedless. [MN 70](https://120-dhammatalks-footnotes/suttas/MN/MN70.html) describes the practices that a stream-enterer still has to do with heedfulness.

[^7]: The Commentary says that Sakka is Ven. Mahā Moggallāna’s fellow in the holy life in the sense that he is a stream-enterer. It calls this kind of holy life a “path holy life *(magga-brahmacariya).”*